pygeodesy.ltpTuples.Los

Package pygeodesy :: Module ltpTuples :: Class Los |
[frames] | no frames]

# Class Los

      object --+
               |
    named._Named --+
                   |
    named._NamedBase --+
                       |
                _AbcBase --+
                           |
                         Aer --+
                               |
                              Los

A Line-Of-Sight (LOS) from a `LatLon` or `Cartesian` location.

Instance Methods
__init__(self, azimuth_aer, elevation=0, **name) New Los. |
toUvw(self, location, Uvw=<class 'pygeodesy.ltpTuples.Uvw'>, **name_Uvw_kwds) Get this LOS' target (UVW) components from a location. |
toEnu(self, Enu=<class 'pygeodesy.ltpTuples.Enu'>, **name_Enu_kwds) Get this LOS as East, North, Up (ENU) components. |
Inherited from `Aer`: `toRepr`, `toStr` Inherited from `_AbcBase`: `toAer`, `toNed`, `toXyz` Inherited from `named._NamedBase`: `__repr__`, `__str__`, `others` Inherited from `named._Named`: `__format__`, `__imatmul__`, `__matmul__`, `__rmatmul__`, `attrs`, `classof`, `copy`, `dup`, `methodname`, `rename`, `renamed`, `toStr2` Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__setattr__`, `__sizeof__`, `__subclasshook__`

Properties
Inherited from `Aer`: `aer4`, `azimuth`, `down`, `east`, `elevation`, `groundrange`, `north`, `slantrange`, `up`, `x`, `xyz4`, `y`, `z` Inherited from `_AbcBase`: `ltp`, `xyz`, `xyz3`, `xyzLocal` Inherited from `named._Named`: `classname`, `classnaming`, `iteration`, `name`, `named`, `named2`, `named3`, `named4`, `sizeof`, `typename` Inherited from `object`: `__class__`

Method Details

### __init__ (self, azimuth_aer, elevation=0, **name) (Constructor) |
New Los. Arguments: `azimuth_aer` - Scalar azimuth, bearing from North (compass `degrees`) or a previous instance (Aer, Aer4Tuple, Enu, Enu4Tuple or Los). `elevation` - Scalar angle above the horizon (`degrees`, horizon is 0, zenith +90, nadir -90), if `azimuth_aer` is `degrees`, ignored otherwise. `name` - Optional `name=NN` (`str`). Raises: `TypeError` - Invalid `azimuth_aer`. `UnitError` - Invalid `azimuth_aer` or `elevation`. Overrides: object.__init__

### toUvw (self, location, Uvw=<class 'pygeodesy.ltpTuples.Uvw'>, **name_Uvw_kwds) |
Get this LOS' target (UVW) components from a location. Arguments: `location` - The geodetic (`LatLon`) or geocentric (`Cartesian`, Vector3d) location from where to cast this LOS. See Also: Method Enu.toUvw for further details.

### toEnu (self, Enu=<class 'pygeodesy.ltpTuples.Enu'>, **name_Enu_kwds) |
Get this LOS as East, North, Up (ENU) components. Arguments: `Enu` - Class to return ENU (Enu) or `None`. `name_Enu_kwds` - Optional `name=NN` (`str`) and optionally, additional Enu keyword arguments, ignored if `Enu is None`. Returns: An `Enu` instance or an Enu4Tuple`(east, north, up, ltp)` if `Enu is None`. Raises: `TypeError` - Invalid `Enu` or `name_Enu_kwds`. Overrides: _AbcBase.toEnu See Also: Method Aer.toEnu for further details.